@@ -1,16 +1,17 @@
 package Amazon::Credentials;
+# - module for finding and providing AWS credentials
 
 use strict;
 use warnings;
 
 use 5.010;
 
-use parent qw{ Exporter Class::Accessor::Fast };
+use parent qw( Exporter Class::Accessor::Fast );
 
 __PACKAGE__->follow_best_practice;
 
 __PACKAGE__->mk_accessors(
-  qw{
+  qw(
     _access_key_id
     cache
     cipher
@@ -41,7 +42,7 @@ __PACKAGE__->mk_accessors(
     sso_region
     timeout
     user_agent
-  }
+  )
 );
 
 use Carp;
@@ -49,20 +50,20 @@ use Config::Tiny;
 use Cwd;
 use Data::Dumper;
 use Date::Format;
-use English qw {-no_match_vars};
+use English qw(-no_match_vars);
 use Exporter;
-use File::chdir;
 use File::HomeDir;
+use File::chdir;
 use HTTP::Request;
-use JSON::PP qw{decode_json encode_json};
+use JSON::PP qw(decode_json encode_json);
 use LWP::UserAgent;
+use List::Util qw(pairs any);
 use MIME::Base64;
-use POSIX::strptime qw/strptime/;
+use POSIX::strptime qw(strptime);
+use Scalar::Util qw(reftype);
 use Time::Local;
-use Scalar::Util qw/reftype/;
-use List::Util qw/pairs any/;
 
-use constant {  ## no critic (ValuesAndExpressions::ProhibitConstantPragma, NamingConventions::Capitalization)
+use constant { ## no critic (ProhibitConstantPragma, Capitalization)
   AWS_AVAILABILITY_ZONE_URL =>
     q{latest/meta-data/placement/availability-zone},
   AWS_CONTAINER_CREDENTIALS_URL    => q{http://169.254.170.2/},
@@ -97,21 +98,22 @@ use constant {  ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Nami
   X_AMZ_SSO_BEARER_TOKEN        => ':x-amz-sso_bearer_token',
 };
 
-our $VERSION = '1.1.15'; ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
+our $VERSION = '1.1.16'; ## no critic (RequireInterpolationOfMetachars)
 
 our @EXPORT_OK
-  = qw{ create_passkey set_sso_credentials get_role_credentials };
+  = qw( create_passkey set_sso_credentials get_role_credentials );
 
 # we only log at debug level, create a default logger
 {
-  no strict 'refs';  ## no critic (TestingAndDebugging::ProhibitNoStrict)
+  no strict 'refs'; ## no critic (ProhibitNoStrict)
 
   *{'Amazon::Credentials::Logger::debug'} = sub {
     my ( $self, @message ) = @_;
 
     return if !$self->{'debug'};
 
-    my @tm        = localtime time;
+    my @tm = localtime time;
+
     my $timestamp = strftime '%c', @tm;
 
     my $message = sprintf LOG_FORMAT, $timestamp, $PROCESS_ID, @message;
@@ -435,9 +437,9 @@ sub get_creds_from_env {
 
   my $creds = {};
 
-  my @cred_keys = qw{ source aws_access_key_id aws_secret_access_key token };
+  my @cred_keys = qw( source aws_access_key_id aws_secret_access_key token );
   my @env_keys
-    = qw{ AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN };
+    = qw( AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN );
 
   if ( $ENV{'AWS_ACCESS_KEY_ID'} && $ENV{'AWS_SECRET_ACCESS_KEY'} ) {
     @{$creds}{@cred_keys} = ( 'ENV', @ENV{@env_keys} );
@@ -472,13 +474,13 @@ sub get_creds_from_process {
 
   $self->get_logger->debug( $self->safe_dumper($credentials) );
 
-  my @credential_keys = qw{
+  my @credential_keys = qw(
     aws_access_key_id AccessKeyId
     aws_secret_access_key SecretAccessKey
     token SessionToken
     region Region
     expiration Expiration
-  };
+  );
 
   foreach my $pair ( pairs @credential_keys ) {
     my ( $k, $v ) = @{$pair};
@@ -538,7 +540,7 @@ sub get_creds_from_ini_file {
   my $creds = {};
   my $region;
 
-  foreach my $config (qw{ .aws/config .aws/credentials }) {
+  foreach my $config (qw( .aws/config .aws/credentials )) {
     last if $creds->{'source'};
 
     my $profile_name = $profile;
@@ -582,12 +584,12 @@ sub get_creds_from_ini_file {
       $region = $section->{'region'} ? $section->{'region'} : $region;
     } ## end if ($process)
     elsif ($section) {
-      my @cred_keys = qw{
+      my @cred_keys = qw(
         aws_access_key_id
         aws_secret_access_key
         token
         region
-      };
+      );
 
       foreach my $k (@cred_keys) {
         if ( defined $section->{$k} ) {
@@ -597,7 +599,7 @@ sub get_creds_from_ini_file {
 
       $creds->{'source'} = $creds->{'aws_access_key_id'} ? $config : undef;
     } ## end elsif ($section)
-  } ## end foreach my $config (qw{ .aws/config .aws/credentials })
+  } ## end foreach my $config (qw( .aws/config .aws/credentials ))
 
   $self->set_region( $creds->{'region'} || $region );
 
@@ -662,10 +664,10 @@ sub get_creds_from_role {
       # if not 200, then get out of Dodge
       last if !$rsp->is_success;
 
-      my @cred_keys = qw{
+      my @cred_keys = qw(
         source role aws_access_key_id aws_secret_access_key
         token expiration
-      };
+      );
 
       if ($role) {
         my $this = decode_json( $rsp->content );
@@ -710,7 +712,7 @@ sub get_creds_from_container {
 
       my $ua  = $self->get_user_agent;
       my $req = HTTP::Request->new( GET => $url );
-      $req->header(qw{ Accept */* });
+      $req->header(qw( Accept */* ));
 
       $self->get_logger->debug( Dumper [ "HTTP REQUEST:\n", $req ] );
 
@@ -1138,14 +1140,14 @@ sub set_sso_credentials {
 
   if ($credentials) {
     foreach my $p (
-      pairs qw{
+      pairs qw(
       accessKeyId AWS_ACCESS_KEY_ID
       secretAccessKey AWS_SECRET_ACCESS_KEY
       sessionToken AWS_SESSION_TOKEN
-      }
+      )
     ) {
 
-      $ENV{ $p->[1] } = sprintf '%s', $credentials->{ $p->[0] };  ## no critic (Variables::RequireLocalizedPunctuationVars)
+      $ENV{ $p->[1] } = sprintf '%s', $credentials->{ $p->[0] }; ## no critic (RequireLocalizedPunctuationVars)
     }
 
   }
@@ -1159,7 +1161,7 @@ sub get_role_credentials {
   my (%args) = @_;
 
   my ( $account_id, $role_name, $access_token, $region )
-    = @args{qw{account_id role_name access_token region}};
+    = @args{qw(account_id role_name access_token region)};
 
   if ( !$access_token ) {
     $access_token = _get_access_token();
@@ -1203,7 +1205,7 @@ sub get_role_credentials {
       croak sprintf "Status: %s\n%s", $rsp->status_line, $content->{message};
     }
     else {
-      croak sprintf "Status: %s\n", $rsp->status_line,
+      croak sprintf "Status: %s\n%s", $rsp->status_line,
         Dumper( $rsp->content );
     }
   }
@@ -1474,7 +1476,7 @@ sub _get_access_token {
 sub help {
 ########################################################################
 
-  print {*STDOUT} <<'EOT';
+  print {*STDOUT} <<'END_OF_USAGE';
 amazon-credentials.sh options
 
 Formats credentials found in env, config, SSO, role
@@ -1482,11 +1484,11 @@ Formats credentials found in env, config, SSO, role
 Options
 -------
 --help, -h     this
---ec2,         get credentials from server IAM profile
---env          get credentials from environment variables
+--ec2, -E      get credentials from server IAM profile
+--envm -e      get credentials from environment variables
 --profile, -p  get credentials from profile in credentials configuration
---role         get credentials from SSO role
---account      use with --role, specify AWS account id
+--role, -r     get credentials from SSO role
+--account, -a  use with --role, specify AWS account id
 
  $ amazon-credentials.sh --profile=test
   export AWS_ACCESS_KEY_ID=AKI*****************
@@ -1494,7 +1496,7 @@ Options
 
  $ aws sso login
  $ amazon-credentials.sh --role my-sso-role --account 01234567890
-EOT
+END_OF_USAGE
 
   exit 0;
 }
@@ -1504,13 +1506,14 @@ sub main {
 ########################################################################
   my ($self) = @_;
 
-  use Getopt::Long;
+  use Getopt::Long qw(:config no_ignore_case);
 
   my %options;
 
   if (
     !GetOptions(
-      \%options, 'help', 'env', 'ec2', 'profile=s', 'role=s', 'account=s'
+      \%options,     'help',     'env|e', 'ec2|E',
+      'profile|p=s', 'role|r=s', 'account|a=s'
     )
   ) {
     help();
@@ -1523,10 +1526,10 @@ sub main {
   if ( $options{role} && $options{account} ) {
     my $credentials
       = Amazon::Credentials::set_sso_credentials(
-      @options{qw{role account region}} );
+      @options{qw(role account region)} );
 
     foreach
-      my $key (qw{AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN})
+      my $key (qw(AWS_ACCESS_KEY_ID AWS_SECRET_ACCESS_KEY AWS_SESSION_TOKEN))
     {
       printf {*STDOUT} sprintf "export %s=%s\n", $key, $ENV{$key} // EMPTY;
     }
@@ -1568,7 +1571,7 @@ Amazon::Credentials - fetch Amazon credentials from file, environment or role
 
 =head1 SYNOPSIS
 
- my @order = qw{ env file container role };
+ my @order = qw( env file container role );
  my $creds = Amazon::Credentials->new( { order => \@order } );
 
 CLI
@@ -1590,11 +1593,11 @@ I<NEW!>
 This class also implements a method for retrieving your SSO
 credentials. By default the method will set the environment variables
 C<AWS_ACCESS_KEY_ID>, C<AWS_SECRET_ACCESS_KEY> and
-C<AWS_SESSION_TOKEN>. Subsequently call C<Amazon::Credentials> to
+C<AWS_SESSION_TOKEN>. Subsequently call L<Amazon::Credentials> to
 retrieve and use the credentials from the localized environment. If
 you only want to retrieve the credentials use C<get_role_credentials>.
 
- use Amazon::Credentials qw{set_sso_credentials get_role_credentials};
+ use Amazon::Credentials qw(set_sso_credentials get_role_credentials);
 
  set_sso_credentials($role_name, $account_id, $region);
  my $credentials = Amazon::Credentials->new;
@@ -1616,8 +1619,8 @@ or pass your SSO role name and account ID...
  
 =head1 VERSION
 
-This document reverse to verion 1.1.15 of
-C<Amazon::Credentials>.
+This document reverse to verion 1.1.16 of
+L<Amazon::Credentials>.
 
 =head1 METHODS AND SUBROUTINES
 
@@ -1649,7 +1652,7 @@ constructor will not look in other places for credentials.>
 
 =item cache
 
-boolean when set to false will prevent C<Amazon::Credentials> from
+boolean when set to false will prevent L<Amazon::Credentials> from
 cacheing credentials. B<Cacheing is enabled by default.>
 
 I<Note that the if cacheing is disabled, the module will obtain
@@ -1676,7 +1679,7 @@ service:
 
 Set to true for verbose troubleshooting information. Set C<logger> to
 a logger that implements a logging interface (ala
-C<Log::Log4perl>.
+L<Log::Log4perl>.
 
 =item decrypt
 
@@ -1837,7 +1840,7 @@ expires.
 =item timeout
 
 When looking for credentials in metadata URLs, this parameter
-specifies the timeout value for C<LWP>.
+specifies the timeout value for L<LWP>.
 
 default: 3s
 
@@ -2057,9 +2060,9 @@ default: $ENV{AWS_REGION}, $ENV{AWS_DEFAULT_REGION}, us-east-1
 Calls C<get_role_credentials> and set AWS credenital environment
 variables. Region is optional, all other parameters are required.
 
- use Amazon::Credentials qw{set_sso_credentials}
+ use Amazon::Credentials qw(set_sso_credentials)
 
- set_sso_credentials(@ENV{qw{AWS_ROLE_NAME AWS_ACCOUNT_ID}});
+ set_sso_credentials(@ENV{qw(AWS_ROLE_NAME AWS_ACCOUNT_ID)});
 
  my $credentials = Amazon::Credentials->new;
 
@@ -2074,7 +2077,7 @@ Example:
 
 =head1 DIAGNOSTICS
 
-Set the C<debug> option when you instantiate a C<Amazon::Credentials>
+Set the C<debug> option when you instantiate a L<Amazon::Credentials>
 object to output debug and diagnostic messages. Note that you must
 also set the C<insecure> option if you want to output full
 diagnostics. I<WARNING: Full diagnostics may include credentials. Be
@@ -2103,7 +2106,7 @@ described throughout this documentation.
 
 =head1 BUGS AND LIMITATIONS
 
-C<Amazon::Credentials> will B<not> attempt to retrieve temporary
+L<Amazon::Credentials> will B<not> attempt to retrieve temporary
 credentials for profiles that specify a role. If for example you
 define a role in your credentials file thusly:
 
@@ -2134,7 +2137,7 @@ Lower versions of these modules may be acceptable.
 ...and possibly others
 
 In order to enable true encryption of your credentials when cached,
-C<Crypt::CBC> is also required.
+L<Crypt::CBC> is also required.
 
 =head1 SECURITY CONSIDERATIONS
 
@@ -2158,15 +2161,15 @@ credentials in plain-text.
 B<Always take precautions to prevent accidental exfiltration of your
 credentials.>
 
-=head2 How C<Amazon::Credentials> Helps Prevent Exfiltration
+=head2 How L<Amazon::Credentials> Helps Prevent Exfiltration
 
 For performance and historical reasons the default is for
-C<Amazon::Credentials> to cache your credentials. Starting with
+L<Amazon::Credentials> to cache your credentials. Starting with
 version I<1.1.0>, the module will attempt to encrypt the credentials
-before storing them. The module uses C<Crypt::CBC> (if available) with
+before storing them. The module uses L<Crypt::CBC> (if available) with
 the default cipher and a random (or user defined) passkey.
 
-Even if C<Crypt::CBC> is not available, the module will try to
+Even if L<Crypt::CBC> is not available, the module will try to
 obfuscate the credentials. A determined actor can still decrypt these
 keys if they have access to the obfuscated values and your
 passkey. You have several options to better secure your credentials
@@ -2182,7 +2185,7 @@ credentials.>
 
  my $credentials = Amazon::Credentials->new(cache => 0);
 
-Normally, your credentials are fetched when the C<Amazon::Credentials>
+Normally, your credentials are fetched when the L<Amazon::Credentials>
 object is instantiated. With cacheing turned off credentials will not
 be fetched until they are first requested.
 
@@ -2196,9 +2199,9 @@ retrieving a hash containing all of the keys.
 
 Use the method C<credential_keys> to retrieve all of the keys at once
 as a hash. Using this method with cacheing turned off will prevent
-C<Amazon::Credentials> from ever saving your credentials to variables
+L<Amazon::Credentials> from ever saving your credentials to variables
 that can be inadvertantly exposed. Each subsequent request for the
-keys will cause C<Amazon::Credentials> to fetch the keys again.
+keys will cause L<Amazon::Credentials> to fetch the keys again.
 
 =item Getter Methods
 
@@ -2219,8 +2222,8 @@ regenerate credentials.
 
 =item Option 3 - Encrypt your credentials
 
-C<Amazon::Credentials> will encrypt your credentials by default
-starting with version I<1.1.0>. If C<Crypt::CBC> is available, the
+L<Amazon::Credentials> will encrypt your credentials by default
+starting with version I<1.1.0>. If L<Crypt::CBC> is available, the
 class will use the default cipher and a random passkey to encrypt your
 credentials. If the encryption module is not available, the class will
 still obfuscate (not encrypt) the credentials. Encryption when the
@@ -2235,13 +2238,13 @@ can and should encrypt credentials in a more secure way.
 By default the module will generate its own random passkey during
 initialization and use that to encrypt and decrypt the
 credentials. Obviously the passkey must be available for
-C<Amazon::Credentials> to decrypt the keys, however it is B<NOT>
+L<Amazon::Credentials> to decrypt the keys, however it is B<NOT>
 stored in the blessed hash reference that stores other data used by
 the class. Instead the passkey is a class variable and will be
-initialized once for all instances of C<Amazon::Credentials> your
+initialized once for all instances of L<Amazon::Credentials> your
 script uses.
 
-If you plan on using multiple instances of C<Amazon::Credentials> B<and>
+If you plan on using multiple instances of L<Amazon::Credentials> B<and>
 you are passing in your own passkeys, then you'll need to reset the
 passkey for each use of the credentials. See the example below in the
 L</Using Multiple Instances of Amazon::Credentials> section.
@@ -2249,7 +2252,7 @@ L</Using Multiple Instances of Amazon::Credentials> section.
 To avoid having the class know about your passkey at all, pass a
 reference to a subroutine that will provide the passkey for encryption
 and decryption. You can even use the same passkey generator that is
-used by C<Amazon::Credentials> (C<create_passkey>).
+used by L<Amazon::Credentials> (C<create_passkey>).
 
 The point here is to avoid storing your passkey in the same object as
 the credentials to minimize the likelihood of exposing your
@@ -2257,7 +2260,7 @@ credentials or your methods for encryption in logs...better but not
 perfect. It's still may be possible to expose your passkey and your
 credentials if you are not careful.
 
- use Amazon::Credentials qw{ create_passkey };
+ use Amazon::Credentials qw( create_passkey );
 
  my $passkey = create_passkey();
 
@@ -2273,7 +2276,7 @@ the passkey inside your program.
 
 You may at times need to assume a role using initial credentials. In
 this case you can use multiple instances of
-C<Amazon::Credentials>. Let's suppose that you have logged in with
+L<Amazon::Credentials>. Let's suppose that you have logged in with
 your SSO credentials but your script must assume a role in another
 account to perform some action.
 
@@ -2318,12 +2321,12 @@ account to perform some action.
   );
 
 As noted above, when you use multiple instances of
-C<Amazon::Credentials>, the I<same> passkey is used for encrypting
+L<Amazon::Credentials>, the I<same> passkey is used for encrypting
 credentials. To avoid this, you can pass a custom passkey when you
-instantiate the C<Amazon::Credentials> object, however, you will need
+instantiate the L<Amazon::Credentials> object, however, you will need
 to reset that passkey when you use that object.
 
- use Amazon::Credentials qw{create_passkey};
+ use Amazon::Credentials qw(create_passkey);
  
  my %passkey = (
    sso  => create_passkey,
@@ -2355,9 +2358,9 @@ to reset that passkey when you use that object.
 
 =item Using a Custom Cipher
 
-As noted, the default C<Crypt::CBC> cipher is used for encrypting your
+As noted, the default L<Crypt::CBC> cipher is used for encrypting your
 credentials, however you can pass a custom cipher supported by
-C<Crypt::CBC> further obfuscating the methods used to encrypt your
+L<Crypt::CBC> further obfuscating the methods used to encrypt your
 credentials.
 
  my $credentials = Amazon::Credentials(
@@ -2378,7 +2381,7 @@ If you are not using a custom passkey...
 ...or if you have a custom passkey generator your subroutine must
 continue to provide the old passkey before you can reset the passkey.
 
- use Amazon::Credentials qw{ create_passkey };
+ use Amazon::Credentials qw( create_passkey );
 
  my $passkey = create_passkey;
 
@@ -2430,7 +2433,7 @@ mechanisms for encryption.
 =head2 Securing Your Logs
 
 To troubleshoot potential bugs in this module or to understand what
-C<Amazon::Credentials> is doing you can pass a debug flag that will
+L<Amazon::Credentials> is doing you can pass a debug flag that will
 write potentially helpful info to STDERR.
 
 To prevent possible exposure of credentials in debug messages, the
@@ -2461,7 +2464,7 @@ enable full debugging.
 
 One additional tip to help prevent the use of your credentials even if
 they have been exposed in logs or files. I<Use temporary credentials
-with short expiration times whenever possible.> C<Amazon::Credentials>
+with short expiration times whenever possible.> L<Amazon::Credentials>
 provides methods to determine if your credentials have expired and
 a method to refresh them when they have.
 
@@ -2484,14 +2487,13 @@ setting the environment variable DEBUG to any true value to enable
 basic debug output. Version I<1.0.18> would log information to STDERR
 including payloads that might contain credentials.  Version I<1.0.19>
 would prevent writing any payload with credentials I<unless> the debug
-mode was set to 2 or 'insecure'.
+mode was set to 2 or 'insecure'.  Keep in mind however that you should
+avoid allowing upstream programs to use environment variables to set
+debugging modes that you might pass to L<Amazon::Credentials>.
 
-Starting with version I<1.1.0> the C<Amazon::Credentials> will not use
-the environment variable DEBUG to enable debugging. You must
-explicitly pass the debug flag in the constructor to enable
-debugging. Keep in mind however that you should avoid allowing
-upstream programs to use environment variables to set debugging modes
-that you might pass to C<Amazon::Credentials>.
+Starting with version I<1.1.0> the L<Amazon::Credentials> will B<not>
+use the environment variable DEBUG to enable debugging! You must
+explicitly pass the debug flag in the constructor to enable debugging. This was done to prevent potential upstream modules that you might use who allow an environment variable to set debug mode to also inadvertantly trigger debug mode for L<Amazon::Credentials>.
 
 =head1 INCOMPATIBILITIES
 
